@@ -1,3 +1,27 @@
+/*****
+ *       Xnee's Not an Event Emulator                                
+ *                                                                   
+ * Xnee enables recording and replaying of X protocol data           
+ *                                                                   
+ *        Copyright (C) 2002, 2003, 2004, 2005 Henrik Sandklef
+ *                                                                   
+ * This program is free software; you can redistribute it and/or     
+ * modify it under the terms of the GNU General Public License       
+ * as published by the Free Software Foundation; either version 2    
+ * of the License, or any later version.                             
+ *                                                                   
+ *                                                                   
+ * This program is distributed in the hope that it will be useful,   
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of    
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     
+ * GNU General Public License for more details.                      
+ *                                                                   
+ * You should have received a copy of the GNU General Public License 
+ * along with this program; if not, write to the Free Software       
+ * Foundation, Inc., 51 Franklin Street, Boston,            
+ * MA  02110-1301, USA.                                              
+ ****/
+
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -448,9 +472,15 @@ on_about1_activate                     (GtkMenuItem     *menuitem,
 				 "about_window");
 
   if (about_box==NULL)
-    about_box = create_about_window();
+    {
+      about_box = create_about_window();
+    }
 
-  gtk_widget_show (about_box);
+
+  if (about_box!=NULL)
+    {
+      gtk_widget_show (about_box);
+    }
 }
 
 
@@ -1485,3 +1515,22 @@ on_record_settings_box_map             (GtkWidget       *widget,
   ;
 }
 
+
+void
+on_button5_clicked                     (GtkButton       *button,
+                                        gpointer         user_data)
+{
+  GtkWidget   *window;
+    
+  if (user_data)
+    {
+      window = lookup_widget(user_data, "about_window");
+    }
+
+  if (window)
+    {
+      gtk_widget_hide (window);
+    }
+}
+
+
