@@ -1,3 +1,27 @@
+/*****
+ *       Xnee's Not an Event Emulator                                
+ *                                                                   
+ * Xnee enables recording and replaying of X protocol data           
+ *                                                                   
+ *   Copyright (C) 2003, 2004, 2005 Henrik Sandklef and Jon-Erling Dahl
+ *                                                                   
+ * This program is free software; you can redistribute it and/or     
+ * modify it under the terms of the GNU General Public License       
+ * as published by the Free Software Foundation; either version 2    
+ * of the License, or any later version.                             
+ *                                                                   
+ *                                                                   
+ * This program is distributed in the hope that it will be useful,   
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of    
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     
+ * GNU General Public License for more details.                      
+ *                                                                   
+ * You should have received a copy of the GNU General Public License 
+ * along with this program; if not, write to the Free Software       
+ * Foundation, Inc., 51 Franklin Street, Boston,            
+ * MA  02110-1301, USA.                                              
+ ****/
+
 #include <gtk/gtk.h>
 
 
@@ -342,3 +366,11 @@ on_replay_settings_box_map             (GtkWidget       *widget,
 void
 on_record_settings_box_map             (GtkWidget       *widget,
                                         gpointer         user_data);
+
+void
+on_button5_clicked                     (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_about_ok_button_clicked             (GtkButton       *button,
+                                        gpointer         user_data);
