@@ -14,7 +14,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, Inc., 51 Franklin Street, Boston, MA  02110-1301, USA.
 */
 
 
@@ -1065,7 +1065,7 @@ xnee_print_xnee_settings (xnee_data* xd, /*@null@*/ FILE* out)
   
   /* Modes */
   fprintf (out,  "\n# Modes (currently not used)\n");
-  fprintf (out,    "%s       %d\n",
+  fprintf (out,    "#%s       %d\n",
 	   XNEE_SYNC_MODE,
 	   xd->sync ); 
 
