@@ -18,8 +18,8 @@
  *                                                                   
  * You should have received a copy of the GNU General Public License 
  * along with this program; if not, write to the Free Software       
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston,            
- * MA  02111-1307, USA.                                              
+ * Foundation, Inc., 51 Franklin Street, Boston,            
+ * MA  02110-1301, USA.                                              
  ****/
 
 
@@ -38,8 +38,16 @@
 #include "libxnee/xnee_display.h"
 
 
+static int loop_nr = 0;
 
 
+int
+xnee_reset_fake( xnee_data *xd)
+{
+    xnee_verbose((xd, "reset fake\n"));
+    loop_nr = 0 ;
+    return XNEE_OK;
+}
 
 static void
 xnee_fake_sleep(unsigned long period)
@@ -77,7 +85,6 @@ xnee_replay_event_handler( xnee_data* xd,
 			   xnee_intercept_data* xindata, 
 			   long int last_elapsed)
 {
-  static int loop_nr = 0;
   
   int           return_value=0;
   unsigned long last_diff = 0;
@@ -108,8 +115,9 @@ xnee_replay_event_handler( xnee_data* xd,
   /* Synchronise the time */
   xnee_verbose((xd,"ev handler  new %lu   old %lu\n",xindata->newtime , xindata->oldtime ));
   record_last_diff = xnee_delta_time(xindata) ; 
+
   record_first_diff = ( xindata->newtime - xd->first_read_time ) ;
-  
+
   /* get the actual difference from last read - 
      we may have had to wait/sleep */
   last_diff = xnee_get_elapsed_time(xd, XNEE_FROM_LAST_READ );
@@ -129,6 +137,7 @@ xnee_replay_event_handler( xnee_data* xd,
       record_first_diff = 0 ;
       loop_nr=2;
     }
+
   /* if the first event is also the 1st entry from recorded file 
      - reset time - should seldom happen */
   if ( (xd->first_replayed_event==XNEE_TRUE) && (last_elapsed == 0 )) 
@@ -139,7 +148,7 @@ xnee_replay_event_handler( xnee_data* xd,
 		     ));
       record_last_diff = 10 ; 
     }
-  speed = xnee_get_speed(xd); 
+  speed = xnee_get_replay_speed(xd); 
   
   if (speed==100)
     {
@@ -168,14 +177,16 @@ xnee_replay_event_handler( xnee_data* xd,
 				     record_last_diff, 
 				     record_first_diff ) ; 
     }
-  
-  
+
+/*   printf ("xnee_calc_sleep_amount : %lu : (%lu) : %lu %lu ?? %d\n",     */
+/* 	  last_diff, first_diff,  */
+/* 	  record_last_diff, record_first_diff, */
+/* 	  sleep_amt);    */
+
+
+
   xnee_verbose((xd, "---  xnee_replay_event_handler \n "));
   
-
-
-  fflush( NULL );
-  
   /* If we use the last args to the XTestFakexxx functions
    * it is harder to synchronize .... 
    * XNEE_FAKE_SLEEP is a macro for usleep 
@@ -219,7 +230,7 @@ xnee_replay_event_handler( xnee_data* xd,
     }
   xnee_verbose((xd, "<--- xnee_replay_event_handler returning after handling of %d \n", 
 		xindata->u.event.type ));
-
+  
   return return_value ;
 }
 
@@ -396,6 +407,7 @@ xnee_fake_motion_event (xnee_data* xd,
   y = xnee_resolution_newy(xd,y);
 
   xnee_verbose((xd, "---> xnee_fake_motion_event\n"));
+  xnee_verbose((xd, "---  delay = %d\n", (int)dtime));
   if (!xnee_is_recorder (xd))
     {
 
