@@ -18,8 +18,8 @@
  *                                                                   
  * You should have received a copy of the GNU General Public License 
  * along with this program; if not, write to the Free Software       
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston,            
- * MA  02111-1307, USA.                                              
+ * Foundation, Inc., 51 Franklin Street, Boston,            
+ * MA  02110-1301, USA.                                              
  ****/
 
 #include "libxnee/xnee.h"
@@ -58,11 +58,13 @@ xnee_open_files(xnee_data *xd)
   char *file_name;
 
   xnee_verbose((xd, "---> xnee_open_files\n"));
+
   file_name = xnee_get_err_name(xd);
   if (file_name!=NULL)
     {
       xnee_verbose((xd, "---  xnee_open_files: handling err\n"));
-      if ((xnee_check (file_name, "stderr", "STDERR")!=XNEE_OK)!=0)
+      if ( ((xnee_check (file_name, "stderr", "STDERR")!=XNEE_OK) != 0) &&
+	   ((xnee_check (file_name, "", "")!=XNEE_OK) != 0) )
 	{
 	  xnee_verbose((xd, "---  xnee_open_files: opening err: %s\n", 
 			xd->err_name));
