@@ -18,8 +18,8 @@
  *                                                                   
  * You should have received a copy of the GNU General Public License 
  * along with this program; if not, write to the Free Software       
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston,            
- * MA  02111-1307, USA.                                              
+ * Foundation, Inc., 51 Franklin Street, Boston,            
+ * MA  02110-1301, USA.                                              
  ****/
 
 
@@ -220,13 +220,18 @@ xnee_add_resource_syntax(xnee_data *xd, char *tmp)
     }
 
   if (!strncmp("#",tmp,1))  /* # META data */
-    {
-/*       xnee_handle_resource_meta (xd, tmp); */
+  {
+      /*       xnee_handle_resource_meta (xd, tmp); */
       if (xnee_handle_meta_data (xd, tmp+1)!=-1) 
-	{ printf ("RETURN\n"); return 1; }
+      { 
+	  xnee_verbose((xd, "  xnee_handle_meta_data: handling #   return 1\n"));
+	  return 1; 
+      }
       else
-	printf ("continue..with: %s\n", ++tmp);
-    }
+      {
+	  xnee_verbose((xd, "  xnee_handle_meta_data: handling #\n"));
+      }
+  }
 
   rem_all_blanks (tmp, len);
   len=strlen(tmp);
